**UzbekStemmer**

version = 0.2.4

authors = [Maksud Sharipov, Ulugbek Salaev, Allabergan Yuldashev, Jasur Sobirov]

maqsbek72@gmail.com ,
ulugbek0302@gmail.com,
 ollaberganyuldashov@gmail.com


Uzbek Stemmer for Python

The Uzbek stemming algorithm was created by [Maksud Sharipov, Ulugbek Salaev, Allabergan Yuldashev, Jasur Sobirov]. It stems all Uzbek words and it is not included any lexicon.

github url: https://github.com/MaksudSharipov/UzbekStemmer

pypi.org url: https://pypi.org/project/UzbekStemmer/

<code>pip install UzbekStemmer</code>
```
Example:
from UzbekStemmer import UzbekStemmer as obj
print(obj.WordStemmer("bolalaringizmi"))
Result: "bola"
```